"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Core(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___Core = Core

@typing.final
class MarketingCloud(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___MarketingCloud = MarketingCloud

@typing.final
class ImportRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CORE_FIELD_NUMBER: builtins.int
    MARKETINGCLOUD_FIELD_NUMBER: builtins.int
    @property
    def core(self) -> global___Core: ...
    @property
    def marketingCloud(self) -> global___MarketingCloud: ...
    def __init__(
        self,
        *,
        core: global___Core | None = ...,
        marketingCloud: global___MarketingCloud | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["core", b"core", "marketingCloud", b"marketingCloud", "productType", b"productType"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["core", b"core", "marketingCloud", b"marketingCloud", "productType", b"productType"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["productType", b"productType"]) -> typing.Literal["core", "marketingCloud"] | None: ...

global___ImportRole = ImportRole

@typing.final
class ExportRole(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_FIELD_NUMBER: builtins.int
    @property
    def input(self) -> global___SinkInput: ...
    def __init__(
        self,
        *,
        input: global___SinkInput | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["input", b"input"]) -> None: ...

global___ExportRole = ExportRole

@typing.final
class SingleFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["name", b"name"]) -> None: ...

global___SingleFile = SingleFile

@typing.final
class RawFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RawFile = RawFile

@typing.final
class ZipFile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SINGLEFILE_FIELD_NUMBER: builtins.int
    @property
    def singleFile(self) -> global___SingleFile: ...
    def __init__(
        self,
        *,
        singleFile: global___SingleFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["selection", b"selection", "singleFile", b"singleFile"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["selection", b"selection", "singleFile", b"singleFile"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["selection", b"selection"]) -> typing.Literal["singleFile"] | None: ...

global___ZipFile = ZipFile

@typing.final
class SinkInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DEPENDENCY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    RAW_FIELD_NUMBER: builtins.int
    ZIP_FIELD_NUMBER: builtins.int
    dependency: builtins.str
    name: builtins.str
    @property
    def raw(self) -> global___RawFile: ...
    @property
    def zip(self) -> global___ZipFile: ...
    def __init__(
        self,
        *,
        dependency: builtins.str = ...,
        name: builtins.str = ...,
        raw: global___RawFile | None = ...,
        zip: global___ZipFile | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["file", b"file", "raw", b"raw", "zip", b"zip"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["dependency", b"dependency", "file", b"file", "name", b"name", "raw", b"raw", "zip", b"zip"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["file", b"file"]) -> typing.Literal["raw", "zip"] | None: ...

global___SinkInput = SinkInput

@typing.final
class SalesforceWorkerConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREDENTIALSDEPENDENCY_FIELD_NUMBER: builtins.int
    IMPORTROLE_FIELD_NUMBER: builtins.int
    EXPORTROLE_FIELD_NUMBER: builtins.int
    DOMAINURL_FIELD_NUMBER: builtins.int
    APINAME_FIELD_NUMBER: builtins.int
    credentialsDependency: builtins.str
    domainUrl: builtins.str
    apiName: builtins.str
    @property
    def importRole(self) -> global___ImportRole: ...
    @property
    def exportRole(self) -> global___ExportRole: ...
    def __init__(
        self,
        *,
        credentialsDependency: builtins.str = ...,
        importRole: global___ImportRole | None = ...,
        exportRole: global___ExportRole | None = ...,
        domainUrl: builtins.str = ...,
        apiName: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["exportRole", b"exportRole", "importRole", b"importRole", "role", b"role"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["apiName", b"apiName", "credentialsDependency", b"credentialsDependency", "domainUrl", b"domainUrl", "exportRole", b"exportRole", "importRole", b"importRole", "role", b"role"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["role", b"role"]) -> typing.Literal["importRole", "exportRole"] | None: ...

global___SalesforceWorkerConfiguration = SalesforceWorkerConfiguration
